@@ -2,7 +2,7 @@
 # Conventional (unscaled) ABE by ANOVA                  #
 # fixed: sequence, subject(sequence), period, treatment #
 #########################################################
-ABE <- function(alpha = 0.05, path.in, path.out, file, set = "",
+ABE <- function(alpha = 0.05, path.in, path.out = tempdir(), file, set = "",
                 ext, na = ".", sep = ",", dec = ".",
                 logtrans = TRUE, print = TRUE, details = FALSE,
                 verbose = FALSE, ask = FALSE, data = NULL,
@@ -10,8 +10,8 @@ ABE <- function(alpha = 0.05, path.in, path.out, file, set = "",
   exec <- strftime(Sys.time(), usetz=TRUE)
   if (!missing(ext)) ext <- tolower(ext) # case-insensitive
   if (missing(theta1) & missing(theta2)) theta1 <- 0.80
-  if (missing(theta1)) theta1 = 1/theta2
-  if (missing(theta2)) theta2 = 1/theta1
+  if (missing(theta1)) theta1 <- 1/theta2
+  if (missing(theta2)) theta2 <- 1/theta1
   ret  <- CV.calc(alpha=alpha, path.in=path.in, path.out=path.out,
                   file=file, set=set, ext=ext, na=na, sep=sep,
                   dec=dec, logtrans=logtrans, ola=FALSE,
@@ -52,9 +52,20 @@ ABE <- function(alpha = 0.05, path.in, path.out, file, set = "",
   }
   if (verbose) {
     name <-  paste0(file, set)
+    len  <- max(27+nchar(name), 35)
     cat(paste0("\nData set ", name, ": ABE by lm()"),
-        paste0("\n", paste0(rep("\u2500", 22+nchar(name)), collapse="")), "\n")
-    print(stats::anova(mod), digits=6, signif.stars=FALSE) # otherwise summary of lmerTest is used
+        paste0("\n", paste0(rep("\u2500", len), collapse = "")), "\n")
+    # change from type I (default as in versions up to 1.0.17)
+    # to type III to get the correct carryover test
+    typeIII <- stats::anova(mod) # otherwise summary of lmerTest is used
+    attr(typeIII, "heading")[1] <- "Type III Analysis of Variance Table\n"
+    MSdenom <- typeIII["sequence:subject", "Mean Sq"]
+    df2     <- typeIII["sequence:subject", "Df"]
+    fvalue  <- typeIII["sequence", "Mean Sq"] / MSdenom
+    df1     <- typeIII["sequence", "Df"]
+    typeIII["sequence", 4] <- fvalue
+    typeIII["sequence", 5] <- pf(fvalue, df1, df2, lower.tail = FALSE)
+    print(typeIII, digits = 6, signif.stars = FALSE)
     cat("\ntreatment T \u2013 R:\n")
     print(signif(summary(mod)$coefficients["treatmentT", ]), 6)
     cat(anova(mod)["Residuals", "Df"], "Degrees of Freedom\n\n")
@@ -83,7 +94,7 @@ ABE <- function(alpha = 0.05, path.in, path.out, file, set = "",
       round(res$"CL.hi(%)", 2) <= 100*theta2)
     res$BE <- "pass" # CI within acceptance range
   options(ow) # restore options
-  if (details) { # results in default (7 digits) precision
+  if (details) { # results in full numeric precision
     ret <- res   # and remove superfluous columns
     #class(ret) <- "repBE"
     return(ret)
@@ -127,8 +138,6 @@ ABE <- function(alpha = 0.05, path.in, path.out, file, set = "",
     txt <- paste0(txt, "\nNote: The extra-reference design assumes lacking period effects. ",
                   "The treatment\ncomparison will be biased in the presence of a ",
                   "true period effect.")
-  if (res$Design %in% c("TRTR|RTRT|TRRT|RTTR", "TRRT|RTTR|TTRR|RRTT"))
-    txt <- paste0(txt, "\nNote: Confounded effects; design not recommended.")
   txt <- paste0(txt, "\n")
   if (print & overwrite) {
     res.file <- file(results, open="ab")                        # line endings
